# CreateSessionFromSnapshotOptions

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**project_id** | **str** |  | 
**name** | **str** |  | 
**snapshot_id** | **str** |  | [optional] 
**session_params** | [**object**](.md) |  | [optional] 
**command_name** | **str** |  | [optional] 
**command_params** | [**object**](.md) |  | [optional] 
**shell** | **bool** |  | [optional] [default to False]
**min_workers** | **int** |  | [optional] 
**max_workers** | **int** |  | [optional] 
**cluster_config** | [**WriteClusterConfig**](WriteClusterConfig.md) |  | [optional] 
**cloud_id** | **str** |  | [optional] 
**start_session** | **bool** |  | [optional] [default to True]
**wait_for_snapshot** | **bool** |  | [optional] [default to False]

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


